@@ -11,7 +11,7 @@ function(data,model,par){
 	if(length(b)==1) b<-rep(b,length=k)
 	if (length(a)==1) a<-matrix(a,k,max(d))
 	else if (length(a)==k) a<-matrix(a,k,max(d))
-	else if (model=='AIBQD') a<-matrix(a,k,d[1],byrow=TRUE)
+	else if (model=='AJBQD') a<-matrix(a,k,d[1],byrow=TRUE)
 	
 	b[b<1e-10]<-1e-10
 	
@@ -26,19 +26,19 @@ function(data,model,par){
 	D<-sum(d)
 	d<-d[1]
 	to<-d*(p-(d+1)/2)
-	if (model=='AKIBKQKDK') m<-ro+tot+2*k+D
+	if (model=='AKJBKQKDK') m<-ro+tot+2*k+D
 	else if (model=='AKBKQKDK') m<-ro+tot+3*k
 	else if (model=='ABKQKDK') m<-ro+tot+2*k+1
-	else if (model=='AKIBQKDK') m<-ro+tot+k+D+1
+	else if (model=='AKJBQKDK') m<-ro+tot+k+D+1
 	else if (model=='AKBQKDK') m<-ro+tot+2*k+1
 	else if (model=='ABQKDK') m<-ro+tot+k+2
-	else if (model=='AKIBKQKD') m<-ro+k*(to+d+1)+1
+	else if (model=='AKJBKQKD') m<-ro+k*(to+d+1)+1
 	else if (model=='AKBKQKD') m<-ro+k*(to+2)+1
 	else if (model=='ABKQKD') m<-ro+k*(to+1)+2
-	else if (model=='AKIBQKD') m<-ro+k*(to+d)+2
+	else if (model=='AKJBQKD') m<-ro+k*(to+d)+2
 	else if (model=='AKBQKD') m<-ro+k*(to+1)+2
 	else if (model=='ABQKD') m<-ro+k*to+3
-	else if (model=='AIBQD') m<-ro+to+d+2
+	else if (model=='AJBQD') m<-ro+to+d+2
 	else if (model=='ABQD') m<-ro+to+3
 	bic<-L+m*log(N)/N
 	return(-bic)
